@@ -618,7 +618,6 @@ class ImageViewer(CompositionMixin, pg.PlotWidget):
     self.toolsEditor = params.ParamEditor(name='Region Tools')
     vb = self.getViewBox()
     self.menu: QtWidgets.QMenu = vb.menu
-    self.menu.clear()
     self.oldVbMenu: ViewBoxMenu = vb.menu
     # Disable default menus
     self.plotItem.ctrlMenu = None
@@ -770,7 +769,10 @@ class MaskCompositor(ImageViewer):
       name = pascalCaseToTitle(name)
       return name
     with nameFormatter.set(newFmt):
-      self.toolsEditor.registerFunc(self.setOverlayProperties, runOpts=params.RunOpts.ON_CHANGED)
+      self.propertiesProc = self.toolsEditor.registerFunc(
+        self.setOverlayProperties,
+        runOpts=params.RunOpts.ON_CHANGED
+      )
       self.toolsEditor.registerFunc(self.save)
       self.toolsEditor.registerFunc(lambda: self.imgItem.setVisible(not self.imgItem.isVisible()),
                                     name='Toggle Image Visible')
@@ -864,26 +866,25 @@ class MaskCompositor(ImageViewer):
       ii += 1
     return name
 
-  def addLabelImg(self, labelImg: np.ndarray, names='Label', ignoreBackground=True):
+  def addLabelMask(self, labelMask: np.ndarray, names='Label', ignoreBackground=True):
     """
     Splits a label mask into its constituent labels and adds a mask for each unique label.
 
-    :param labelImg: Grayscale label mask of integers
+    :param labelMask: Grayscale label mask of integers
     :param names: Base name of each label. E.g. if 3 labels are present in the image, the
       resulting masks will be named <name> 1, <name> 2, <name 3>. Alternatively,
       a list of names can be provided
     :param ignoreBackground: Whether a mask should be added for 0-valued labels (typically
       0 is used to denote background / non-label values)
     """
-    labels = np.unique(labelImg)
+    labels = np.unique(labelMask)
     if ignoreBackground:
       labels = labels[labels > 0]
-    newMasks = [labelImg == label for label in labels]
+    newMasks = [labelMask == label for label in labels]
     if not is_sequence(names):
       names = [f'{names} {ii}' for ii in labels]
     self.addMasks(newMasks, names)
 
-
   def setLegendFontStyle(self, startItemIdx=0, **lblTxtArgs):
     for item in self.legend.items[startItemIdx:]:
       for single_item in item:
@@ -933,7 +934,7 @@ class MaskCompositor(ImageViewer):
     self.legend.autoAnchor(imPos)
 
   def _updateGraphics(self):
-    self.setOverlayProperties()
+    self.propertiesProc.run()
 
   def clearOverlays(self):
     for imgItem in self.recordDf['item']:
